@@ -12,12 +12,11 @@
 #
 ##############################################################################
 from zope.configuration import xmlconfig
-from zope.app.component import hooks # BBB: import from zope.site at a later date
 from zope.testing.cleanup import cleanUp
 import wsgi_intercept
 
 def null_layer(layer):
-    """Sets up a class as a layer that doesn nothing.
+    """Sets up a class as a layer that does nothing.
 
     Useful if you want a layer to inherit from other layers but not inherit
     their methods. Inheriting the method can cause it to be triggered twice as
@@ -77,7 +76,6 @@ def zcml_layer(layer):
     """
 
     def setUp(cls):
-        hooks.setHooks()
         context = xmlconfig.file(cls.zcml)
     layer.setUp = classmethod(setUp)
 
@@ -104,24 +102,31 @@ class ErrorHandler:
     def __call__(self, environ, start_response):
         if environ.get('HTTP_X_ZOPE_HANDLE_ERRORS') == 'False':
             environ['wsgi.handleErrors'] = False
+        if 'HTTP_X_ZOPE_HANDLE_ERRORS' in environ:
+            del environ['HTTP_X_ZOPE_HANDLE_ERRORS']
         def my_start_response(status, headers, exc_info=None):
+            # Behave like zope.testbrowser.testing:
+            # sort response headers and insert status code in first place.
             headers = sorted(headers)
             headers.insert(0, ('Status', status))
-            return start_response(status, sorted(headers), exc_info=exc_info)
+            return start_response(status, headers, exc_info=exc_info)
         return self.application(environ, my_start_response)
 
 
 def wsgi_intercept_layer(layer):
 
+    domain = getattr(layer, 'domain', 'localhost')
+    port = getattr(layer, 'port', 80)
+
     def make_debug_application():
         return ErrorHandler(layer.make_application())
 
     def setUp(cls):
-        wsgi_intercept.add_wsgi_intercept('localhost', 80, make_debug_application)
+        wsgi_intercept.add_wsgi_intercept(domain, port, make_debug_application)
     layer.setUp = classmethod(setUp)
 
     def tearDown(cls):
-        wsgi_intercept.remove_wsgi_intercept('localhost', 80)
+        wsgi_intercept.remove_wsgi_intercept(domain, port)
 
     def null(cls):
         pass
